@@ -53,19 +53,19 @@ class TestProcessDriversAndHardwareTypes(base.TestCase):
         self.assertEqual({
             'IronicEnabledNetworkInterfaces': ['flat'],
             'IronicDefaultNetworkInterface': 'flat',
-            'IronicEnabledHardwareTypes': ['idrac', 'ilo', 'ipmi', 'redfish'],
-            'IronicEnabledBootInterfaces': ['ilo-pxe', 'ipxe', 'pxe'],
-            'IronicEnabledBiosInterfaces': ['ilo', 'no-bios', 'redfish'],
-            'IronicEnabledDeployInterfaces': ['ansible', 'direct', 'iscsi'],
-            'IronicEnabledInspectInterfaces': ['idrac', 'ilo', 'inspector',
-                                               'no-inspect', 'redfish'],
-            'IronicEnabledManagementInterfaces': ['fake', 'idrac', 'ilo',
-                                                  'ipmitool', 'noop',
-                                                  'redfish'],
-            'IronicEnabledPowerInterfaces': ['fake', 'idrac', 'ilo',
-                                             'ipmitool', 'redfish'],
-            'IronicEnabledRaidInterfaces': ['idrac', 'no-raid'],
-            'IronicEnabledVendorInterfaces': ['idrac', 'ipmitool', 'no-vendor']
+            'IronicEnabledHardwareTypes': ['ipmi', 'redfish', 'ilo', 'idrac'],
+            'IronicEnabledBootInterfaces': ['ipxe', 'pxe', 'ilo-pxe'],
+            'IronicEnabledBiosInterfaces': ['no-bios', 'ilo', 'redfish'],
+            'IronicEnabledDeployInterfaces': ['direct', 'iscsi', 'ansible'],
+            'IronicEnabledInspectInterfaces': ['inspector', 'no-inspect',
+                                               'redfish', 'idrac', 'ilo'],
+            'IronicEnabledManagementInterfaces': ['ipmitool', 'redfish',
+                                                  'idrac', 'ilo', 'fake',
+                                                  'noop'],
+            'IronicEnabledPowerInterfaces': ['ipmitool', 'redfish',
+                                             'idrac', 'ilo', 'fake'],
+            'IronicEnabledRaidInterfaces': ['no-raid', 'idrac'],
+            'IronicEnabledVendorInterfaces': ['no-vendor', 'ipmitool', 'idrac']
         }, env)
 
     def test_one_hardware_type_with_discovery(self):
@@ -78,17 +78,17 @@ class TestProcessDriversAndHardwareTypes(base.TestCase):
             'IronicEnabledNetworkInterfaces': ['flat'],
             'IronicDefaultNetworkInterface': 'flat',
             # ipmi added because it's the default discovery driver
-            'IronicEnabledHardwareTypes': ['ipmi', 'redfish'],
+            'IronicEnabledHardwareTypes': ['redfish', 'ipmi'],
             'IronicEnabledBootInterfaces': ['ipxe', 'pxe'],
             'IronicEnabledBiosInterfaces': ['no-bios', 'redfish'],
-            'IronicEnabledDeployInterfaces': ['ansible', 'direct', 'iscsi'],
+            'IronicEnabledDeployInterfaces': ['direct', 'iscsi', 'ansible'],
             'IronicEnabledInspectInterfaces': ['inspector', 'no-inspect',
                                                'redfish'],
-            'IronicEnabledManagementInterfaces': ['fake', 'ipmitool',
-                                                  'noop', 'redfish'],
-            'IronicEnabledPowerInterfaces': ['fake', 'ipmitool', 'redfish'],
+            'IronicEnabledManagementInterfaces': ['ipmitool', 'redfish',
+                                                  'fake', 'noop'],
+            'IronicEnabledPowerInterfaces': ['ipmitool', 'redfish', 'fake'],
             'IronicEnabledRaidInterfaces': ['no-raid'],
-            'IronicEnabledVendorInterfaces': ['ipmitool', 'no-vendor'],
+            'IronicEnabledVendorInterfaces': ['no-vendor', 'ipmitool'],
             'IronicInspectorDiscoveryDefaultDriver': 'ipmi',
             'IronicInspectorEnableNodeDiscovery': True
         }, env)
@@ -105,28 +105,27 @@ class TestProcessDriversAndHardwareTypes(base.TestCase):
         self.assertEqual({
             'IronicEnabledNetworkInterfaces': ['flat'],
             'IronicDefaultNetworkInterface': 'flat',
-            'IronicEnabledHardwareTypes': ['fake-hardware', 'idrac', 'ilo',
-                                           'ipmi', 'irmc', 'redfish', 'snmp',
-                                           'staging-ovirt', 'xclarity'],
-            'IronicEnabledBootInterfaces': ['fake', 'ilo-pxe', 'ipxe',
-                                            'irmc-pxe', 'pxe'],
-            'IronicEnabledBiosInterfaces': ['ilo', 'irmc',
-                                            'no-bios', 'redfish'],
-            'IronicEnabledDeployInterfaces': ['ansible', 'direct', 'fake',
-                                              'iscsi'],
-            'IronicEnabledInspectInterfaces': ['idrac', 'ilo', 'inspector',
-                                               'irmc', 'no-inspect',
-                                               'redfish'],
-            'IronicEnabledManagementInterfaces': ['fake', 'idrac',
-                                                  'ilo', 'ipmitool', 'irmc',
-                                                  'noop', 'redfish',
-                                                  'staging-ovirt', 'xclarity'],
-            'IronicEnabledPowerInterfaces': ['fake', 'idrac',
-                                             'ilo', 'ipmitool', 'irmc',
-                                             'redfish', 'snmp',
-                                             'staging-ovirt', 'xclarity'],
-            'IronicEnabledRaidInterfaces': ['idrac', 'no-raid'],
-            'IronicEnabledVendorInterfaces': ['idrac', 'ipmitool', 'no-vendor']
+            'IronicEnabledHardwareTypes': ['ipmi', 'redfish', 'ilo', 'idrac',
+                                           'staging-ovirt', 'snmp', 'irmc',
+                                           'xclarity', 'fake-hardware'],
+            'IronicEnabledBootInterfaces': ['ipxe', 'pxe', 'ilo-pxe',
+                                            'irmc-pxe', 'fake'],
+            'IronicEnabledBiosInterfaces': ['no-bios', 'ilo', 'irmc',
+                                            'redfish'],
+            'IronicEnabledDeployInterfaces': ['direct', 'iscsi', 'ansible',
+                                              'fake'],
+            'IronicEnabledInspectInterfaces': ['inspector', 'no-inspect',
+                                               'redfish', 'idrac', 'ilo',
+                                               'irmc'],
+            'IronicEnabledManagementInterfaces': ['ipmitool', 'redfish',
+                                                  'idrac', 'ilo', 'irmc',
+                                                  'staging-ovirt', 'xclarity',
+                                                  'fake', 'noop'],
+            'IronicEnabledPowerInterfaces': ['ipmitool', 'redfish', 'idrac',
+                                             'ilo', 'irmc', 'staging-ovirt',
+                                             'xclarity', 'fake', 'snmp'],
+            'IronicEnabledRaidInterfaces': ['no-raid', 'idrac'],
+            'IronicEnabledVendorInterfaces': ['no-vendor', 'ipmitool', 'idrac']
         }, env)
 
 
